 H1, H2, H3, H4, H5, H6, P, UL, OL, DIR, MENU, DIV, 
 DT, DD, ADDRESS, BLOCKQUOTE, PRE, HR, FORM, DL, 
 LISTING 
      { 
	margin-left: 2%;
	display: block ;
      }

 BODY { 
 	background-color:white; 
 	margin-left: 3%; margin-right: 3%; 
      }

 P    { 
        margin-top:  0%; margin-bottom:   0%;
        margin-left:  0%; 
      }

 H1   { text-align: center; }
 H3   { color:#009900; margin-left: 0%; }
 H4   { color:#009900; margin-left: 0%; 
 	margin-top: 1em; margin-bottom: 0;
      }
 H5   { color:#006600; margin-left: 3%; font-size:larger; }

 IMG  { border-style: none; }

 DT   { 
	color:#006600;
	font-weight: bold; 
	margin-left: 4%; margin-right: 4%; 
	margin-top: 3px;
      }
 DD   {
	margin-left: 8%; margin-right: 8%; 
	margin-top: 3px;
      }

 TABLE	{
 	border: 0;
	}

 TD     {
 	vertical-align: top;
	}

 TD.TD0 { 
 	font-weight: bold; font-size: 67%; 
	color:#006600; 
	padding-top: 0; padding-left: 3em;
	vertical-align: top;
	}

 TD.TD1 { 
 	font-weight: bold; font-size: 67%; 
	padding-top: 0;
	}

 TD.LIMG {
 	padding-right: 40pt;
	vertical-align: top;
	}

 LISTING, PRE 
	{
	margin-left: 2%   ;
 	line-height: 1.00 ;
	font-size: smaller ;
	}

 UL	{
	margin-left:  0.1em ;
	padding-left: 0.1em ;
	margin-top:  0;
	padding-top: 0;
 	}

 LI	{
 	font-size: smaller ;
	text-indent: 1em ;
 	list-style-type: none;
	}

 table	{ border: 0; vertical-align: text-top; }

 .icon-image	{ float:right; margin: 0 0 0 0; }

 div.box	{ border: none; border-width: thin; 
 		  margin-top: 5px; margin-bottom: 5px; 
		  background: #AADDFF;
		  text-align: center;
		}
 div.newitem	{ border-left-style: double; border-color: #006600;
		  text-align: left; text-indent: 0px;
		}
 div.color1	{ border: none;  background: #AADDFF; padding: 0.5em; }
 div.footer	{ border: solid; border-width: thin; 
 		  margin-top: 20px; 
		  margin-left: 0%; margin-right: 0%;
		  padding: 10px;
		}

.float-right	{ float: right; }
